<?php
/**
 * メインプラグインクラス
 */
class AnimaGate_AI_Suite {
    // プロパティを private から protected に変更
    protected $plugin_options;
    private $admin;
    private $generator;

    public function __construct() {
        $this->plugin_options = get_option('animagate_ai_suite_options', array());
        $this->load_dependencies();
    }

    /**
     * プラグインオプションを取得するゲッターメソッド
     *
     * @return array プラグインオプション
     */
    public function get_plugin_options() {
        return $this->plugin_options;
    }

    /**
     * 依存関係の読み込み
     */
    private function load_dependencies() {
        $this->admin = new AnimaGate_AI_Suite_Admin($this->plugin_options);
        $this->generator = new AnimaGate_AI_Suite_Generator($this->plugin_options);

        // ブロックエディター統合
        new AnimaGate_AI_Suite_Editor($this->plugin_options);
    }

    /**
     * プラグインの実行
     */
    public function run() {
        // プラグインの初期化
        add_action('init', array($this, 'init'));
        
        // 管理画面の初期化
        $this->admin->init();
        
        // ジェネレーターの初期化
        $this->generator->init();
    }

    /**
     * プラグインの初期化
     */
    public function init() {
        // 多言語対応の準備
        load_plugin_textdomain(AGAS_TEXT_DOMAIN, false, dirname(plugin_basename(__FILE__)) . '/languages');
    }

    /**
     * プラグインのアクティベーション時の処理
     */
    public static function activate() {
        // オプションの初期値設定
        $default_options = array(
            'api_key' => '',
            'model' => 'gpt-3.5-turbo',
            'max_tokens' => 1500,
            'temperature' => 0.7
        );
        
        add_option('animagate_ai_suite_options', $default_options);
        
        // キャッシュディレクトリの作成
        $upload_dir = wp_upload_dir();
        $cache_dir = $upload_dir['basedir'] . '/animagate-ai-suite-cache';
        
        if (!file_exists($cache_dir)) {
            wp_mkdir_p($cache_dir);
        }
        
        // index.php ファイルを作成してディレクトリリスティングを防止
        $index_file = $cache_dir . '/index.php';
        if (!file_exists($index_file)) {
            $file_handle = @fopen($index_file, 'w');
            if ($file_handle) {
                fwrite($file_handle, "<?php // Silence is golden");
                fclose($file_handle);
            }
        }
        
        // .htaccess ファイルを作成してアクセスを制限
        $htaccess_file = $cache_dir . '/.htaccess';
        if (!file_exists($htaccess_file)) {
            $file_handle = @fopen($htaccess_file, 'w');
            if ($file_handle) {
                fwrite($file_handle, "Deny from all");
                fclose($file_handle);
            }
        }
    }
}