<?php
/**
 * 記事生成フォームのテンプレート
 */
// 直接アクセス禁止
if (!defined('ABSPATH')) {
    exit;
}
?>
<div class="wrap">
    <h1><?php echo esc_html__('AI記事生成', AGAS_TEXT_DOMAIN); ?></h1>
    
    <div class="animagate-ai-suite-container">
        <div class="ai-content-form">
            <h2><?php echo esc_html__('新規記事の生成', AGAS_TEXT_DOMAIN); ?></h2>
            
            <form id="generate-content-form">
                <table class="form-table">
                    <tr>
                        <th scope="row">
                            <label for="content_title"><?php echo esc_html__('タイトル', AGAS_TEXT_DOMAIN); ?></label>
                        </th>
                        <td>
                            <input type="text" id="content_title" name="content_title" class="regular-text" placeholder="<?php echo esc_attr__('記事のタイトル', AGAS_TEXT_DOMAIN); ?>" required>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="content_keywords"><?php echo esc_html__('キーワード', AGAS_TEXT_DOMAIN); ?></label>
                        </th>
                        <td>
                            <input type="text" id="content_keywords" name="content_keywords" class="regular-text" placeholder="<?php echo esc_attr__('カンマ区切りのキーワード', AGAS_TEXT_DOMAIN); ?>">
                            <p class="description"><?php echo esc_html__('複数のキーワードはカンマで区切ってください', AGAS_TEXT_DOMAIN); ?></p>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="content_type"><?php echo esc_html__('記事タイプ', AGAS_TEXT_DOMAIN); ?></label>
                        </th>
                        <td>
                            <select id="content_type" name="content_type">
                                <option value="blog"><?php echo esc_html__('ブログ記事', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="news"><?php echo esc_html__('ニュース記事', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="review"><?php echo esc_html__('レビュー', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="howto"><?php echo esc_html__('ハウツー記事', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="listicle"><?php echo esc_html__('リスト記事', AGAS_TEXT_DOMAIN); ?></option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="content_length"><?php echo esc_html__('記事の長さ', AGAS_TEXT_DOMAIN); ?></label>
                        </th>
                        <td>
                            <select id="content_length" name="content_length">
                                <option value="short"><?php echo esc_html__('短い（約500字）', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="medium" selected><?php echo esc_html__('中程度（約1000字）', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="long"><?php echo esc_html__('長い（約2000字）', AGAS_TEXT_DOMAIN); ?></option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="content_tone"><?php echo esc_html__('トーン', AGAS_TEXT_DOMAIN); ?></label>
                        </th>
                        <td>
                            <select id="content_tone" name="content_tone">
                                <option value="casual"><?php echo esc_html__('カジュアル', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="professional" selected><?php echo esc_html__('プロフェッショナル', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="friendly"><?php echo esc_html__('フレンドリー', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="academic"><?php echo esc_html__('アカデミック', AGAS_TEXT_DOMAIN); ?></option>
                                <option value="funny"><?php echo esc_html__('ユーモア', AGAS_TEXT_DOMAIN); ?></option>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="additional_instructions"><?php echo esc_html__('追加指示', AGAS_TEXT_DOMAIN); ?></label>
                        </th>
                        <td>
                            <textarea id="additional_instructions" name="additional_instructions" class="large-text" rows="4" placeholder="<?php echo esc_attr__('AIに対する追加の指示があれば入力してください', AGAS_TEXT_DOMAIN); ?>"></textarea>
                            <p class="description"><?php echo esc_html__('特定のフォーマットや含めたい内容など、詳細な指示を入力できます', AGAS_TEXT_DOMAIN); ?></p>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label><?php echo esc_html__('オプション', AGAS_TEXT_DOMAIN); ?></label>
                        </th>
                        <td>
                            <label>
                                <input type="checkbox" id="auto_headings" name="auto_headings" value="1" checked>
                                <?php echo esc_html__('見出しを自動生成', AGAS_TEXT_DOMAIN); ?>
                            </label>
                            <br>
                            <label>
                                <input type="checkbox" id="add_conclusion" name="add_conclusion" value="1" checked>
                                <?php echo esc_html__('まとめ・結論を追加', AGAS_TEXT_DOMAIN); ?>
                            </label>
                            <br>
                            <label>
                                <input type="checkbox" id="include_faq" name="include_faq" value="1">
                                <?php echo esc_html__('FAQセクションを追加', AGAS_TEXT_DOMAIN); ?>
                            </label>
                        </td>
                    </tr>
                </table>
                
                <p class="submit">
                    <button type="submit" id="generate-content-button" class="button button-primary">
                        <?php echo esc_html__('記事を生成', AGAS_TEXT_DOMAIN); ?>
                    </button>
                    <span id="generation-status" class="hidden"></span>
                </p>
            </form>
            
            <!-- 通知メッセージのコンテナ -->
            <div id="generation-result-container"></div>
        </div>
        
        <div class="ai-content-history">
            <h2><?php echo esc_html__('最近生成した記事', AGAS_TEXT_DOMAIN); ?></h2>
            <?php (new AnimaGate_AI_Suite_Admin($GLOBALS['animagate_ai_suite']->get_plugin_options()))->render_recent_generated_content(); ?>
        </div>
    </div>
</div>

<!-- WordPress管理画面の通知システムとの互換性を確保 -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    // WordPress組み込みの通知処理をロード
    (function() {
        try {
            if (typeof wp !== 'undefined' && wp.notices && wp.notices.store) {
                console.log('WordPress notice system detected');
            }
        } catch (e) {
            console.log('WordPress notice system not available');
        }
    })();
});
</script>